#ifndef NT2_INCLUDE_FUNCTIONS_FFS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FFS_HPP_INCLUDED

#include <nt2/bitwise/include/functions/ffs.hpp>

#endif
